# Contributing

We welcome contributions to the picosdk-python-examples repository. By contributing to this repository, you agree to abide by our [code of conduct](CODE_OF_CONDUCT.md).

## Steps to contribute

1. Fork, then clone the repository:

```
git clone https://github.com/YOUR-USERNAME/picosdk-python-wrappers.git
```

2. Create a new branch - specify a name in lowercase, using hyphens to link words e.g. `fft-example`

3. Push to the new branch on your fork, and then submit a pull request.

We will then review the pull request.

## Pull request guidelines

* Follow the conventions in the other file headers if adding a new file, or changing an existing file
* If contributing a new file, ensure that it is in the appropriate location in the repository directory structure
* [Commit messages](https://chris.beams.io/posts/git-commit/#seven-rules) should clearly communicate the reason for the change